dofile( "mods/misc_perks/config.lua")
table.insert( perk_list,
	{
		id = "DOUBLE_CAST",
		ui_name = "Double Cast",
		ui_description = "Always cast an extra spell",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/double_cast.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/double_cast.png",
		game_effect = "CAST_AMOUNT_BOOST",
		not_in_default_perk_pool = cfg_enable_double_cast,
		func = function( entity_perk_item, entity_who_picked, item_name )
			EntityAddComponent( entity_who_picked, "ShotEffectComponent", 
			{ 
				extra_modifier = "cast_amount_boost",
			} )
		end,
	})

table.insert( perk_list,
	{
		id = "ACHIEVED_ALCHEMIST",
		ui_name = "Achieved Alchemist",
		ui_description = "Metals and gems in your proximity are converted to gold, but your health has taken a toll",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/achieved_alchemist.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/achieved_alchemist.png",
		game_effect = "COLLECT_METALS_AS_GOLD",
		not_in_default_perk_pool = cfg_disable_achieved_alchemist,
		func = function( entity_perk_item, entity_who_picked, item_name )
			local x, y = EntityGetTransform( entity_who_picked )
			local effect_id = EntityLoad("mods/misc_perks/files/entities/metal_to_gold.xml", x, y)
			EntityAddChild( entity_who_picked, effect_id )

			local damagemodels = EntityGetComponent( entity_who_picked, "DamageModelComponent" )
			if( damagemodels ~= nil ) then
				for i,damagemodel in ipairs(damagemodels) do
					local hp = tonumber( ComponentGetValue( damagemodel, "hp" ) )
					local max_hp = tonumber( ComponentGetValue( damagemodel, "max_hp" ) )
					local max_hp_cap = tonumber( ComponentGetValue( damagemodel, "max_hp_cap" ) )
					
					ComponentSetValue( damagemodel, "hp", math.min( hp, 4 ) )
					ComponentSetValue( damagemodel, "max_hp", math.max( max_hp / 4, 4 ) )
				end
			end
		end,
	})

table.insert( perk_list,
	{
		id = "TRAIL_BLAZER",
		ui_name = "Trailblazer",
		ui_description = "You are immune to fire, but constantly emit sparks",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/trail_blazer.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/trail_blazer.png",
		game_effect = "PROTECTION_FIRE",
		not_in_default_perk_pool = cfg_disable_trail_blazer,
		func = function( entity_perk_item, entity_who_picked, item_name )
			local x, y = EntityGetTransform( entity_who_picked )
			local effect_id = EntityLoad("mods/misc_perks/files/entities/fire_spitter.xml", x, y)
			EntityAddChild( entity_who_picked, effect_id )
		end,
	})

table.insert( perk_list,
	{
		id = "INVENTORY_EXPANSION",
		ui_name = "Expand Inventory",
		ui_description = "You can hold more " .. --[["wands, items, and " .. --]] "spells at once",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/inventory_expansion.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/inventory_expansion.png",
		game_effect = "EXPANDED_INVENTORY",
		not_in_default_perk_pool = cfg_disable_inventory_expansion,
		func = function( entity_perk_item, entity_who_picked, item_name )
			local inventories = EntityGetComponent( entity_who_picked, "Inventory2Component" )
			if( inventories ~= nil ) then
				for i,inventory in ipairs(inventories) do
					ComponentSetValue( inventory, "full_inventory_slots_y", 2 )
					--ComponentSetValue( inventory, "quick_inventory_slots", 16 ) --this doesn't do anything :/
				end
			end
		end,
	})

table.insert( perk_list,
	{
		id = "CHROMATIC_CAPE",
		ui_name = "Chromatic Cape",
		ui_description = "Your cape is now very flashy :)",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/chromatic_cape.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/chromatic_cape.png",
		not_in_default_perk_pool = cfg_disable_chromatic_cape,
		func = function( entity_perk_item, entity_who_picked, item_name )
			EntityAddComponent( entity_who_picked, "LuaComponent", { script_source_file = "mods/misc_perks/files/scripts/rainbow_cape.lua", execute_every_n_frame = "5" } )
		end,
	})

table.insert( perk_list,
	{
		id = "REVENGE_NUKE",
		ui_name = "Revenge Nuke",
		ui_description = "Launches a nuke whenever you take damage...",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/revenge_nuke.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/revenge_nuke.png",
		not_in_default_perk_pool = cfg_disable_revenge_nuke,
		func = function( entity_perk_item, entity_who_picked, item_name )
			EntityAddComponent( entity_who_picked, "LuaComponent", { script_damage_received = "mods/misc_perks/files/scripts/revenge_nuke.lua", execute_every_n_frame = "-1" } )
		end,
	})

for i=1,#perk_list do
	if perk_list[i]["id"] == "MYSTERY_EGGPLANT" then
		perk_list[i]["not_in_default_perk_pool"] = cfg_disable_mystery_eggplant
		perk_list[i]["ui_icon"] = "mods/misc_perks/files/perks_gfx/ui/mystery_eggplant.png"
		perk_list[i]["func"] = function( entity_perk_item, entity_who_picked, item_name )
			EntityAddComponent( entity_who_picked, "LuaComponent", { script_source_file = "mods/misc_perks/files/scripts/eggplant_script_lol.lua", script_damage_received = "mods/misc_perks/files/scripts/eggplant_script_lol.lua" })
		end
	end
end

--[[ why the fuck does the game store the damage materials in a private thing >:(
table.insert( perk_list,
	{
		id = "LAVA_WADERS",
		ui_name = "Lava Waders",
		ui_description = "You are immune to lava",
		ui_icon = "mods/misc_perks/files/perks_gfx/ui/lava_waders.png",
		perk_icon = "mods/misc_perks/files/perks_gfx/ig/lava_waders.png",
		game_effect = "LAVA_IMMUNITY",
		not_in_default_perk_pool = cfg_disable_lava_waders,
		func = function( entity_perk_item, entity_who_picked, item_name )
			local damagers = EntityGetComponent( entity_who_picked, "DamageModelComponent" )
			if damagers ~= nil then
				for _,damager in ipairs(damagers) do
					local cell = ComponentGetValue( damager, "mDamageMaterials" ) -- the private value is annoying
					local damg = ComponentGetValue( damager, "mDamageMaterialsHowMuch" )
					print( "before", tostring(cell), damg )
					local cell_t, damg_t = {}, {}
					for word in string.gmatch( damg, "[^,]+") do
						table.insert( damg_t, word )
					end
					local toomanyvariables = 0
					for word in string.gmatch( cell, "[^,]+") do
						toomanyvariables = toomanyvariables + 1
						print(word)
						if word == "lava" then
							damg_t[toomanyvariables] = ""
							table.insert( cell_t, "" )
						else
							table.insert( cell_t, word )
						end
					end
					cell, damg = "", ""
					for i = 1, #cell_t do
						if cell_t[i] ~= "" then
							cell = cell .. cell_t[i] .. ","
						end
					end
					for i = 1, #damg_t do
						if cell_t[i] ~= "" then
							damg = damg .. damg_t[i] .. ","
						end
					end
					print( "after", cell, damg )
					ComponentSetValue( damager, "mDamageMaterials", cell )
					ComponentSetValue( damager, "mDamageMaterialsHowMuch", damg )
					print( "true after", ComponentGetValue( damager, "mDamageMaterials"), ComponentGetValue( damager, "mDamageMaterialsHowMuch" ))
				end
			end
		end,
	})
]]